@@ -6,7 +6,7 @@ import sys
 sys.path.append('/usr/lib/pearllinux/common')
 import additionalfiles
 
-DOMAIN = "pearl-common"
+DOMAIN = "mint-common"
 PATH = "/usr/share/pearllinux/locale"
 
 prefix = "[Nemo Action]\n"
